/* clang-format off */
/* WARNING: do not edit! */
/* Generated by Makefile from include/crypto/dso_conf.h.in */
/* clang-format on */
/*
 * Copyright 2016-2021 The OpenSSL Project Authors. All Rights Reserved.
 *
 * Licensed under the Apache License 2.0 (the "License").  You may not use
 * this file except in compliance with the License.  You can obtain a copy
 * in the file LICENSE in the source distribution or at
 * https://www.openssl.org/source/license.html
 */

#ifndef OSSL_CRYPTO_DSO_CONF_H
#define OSSL_CRYPTO_DSO_CONF_H
#pragma once

/* clang-format off */
# define DSO_DLFCN
# define HAVE_DLFCN_H
/* clang-format on */
/* clang-format off */
# define DSO_EXTENSION ".so"
/* clang-format on */
#endif
